@@ -63,7 +63,7 @@ typedef struct
   HildonIMUI *ui;
 }
 HildonIMKeyboardDecoratorPrivate;
-static dbus_conn* conn = NULL;
+static fcitm_kbd* conn = NULL;
 static HildonIMUI *client = NULL;
 static GtkWidget *window = NULL, *label = NULL;
 static GtkWidget* buttons[5];
@@ -162,7 +162,7 @@ module_init(GTypeModule *module)
                               HILDON_IM_TYPE_PLUGIN,
                               &plugin_info);
   if(conn==NULL)
-    conn = dbus_conn_new();
+    conn = fcitm_kbd_new();
 }
 
 /*
@@ -473,7 +473,7 @@ hildon_im_keyboard_decorator_enable(HildonIMPlugin *plugin, gboolean init)
 
   client = priv->ui;
   if (window == NULL){
-    dbus_conn_set_key_func( conn, fake_key_press);
+    fcitm_kbd_set_key_func( conn, fake_key_press);
     create_window();
   }
   hildon_im_ui_send_communication_message(priv->ui,
